clear all
%close all 
tic
p = LoadPath()                                                             ;


%%
%%%%%%%%%% Load all data and conbine them %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Folder         = "P:\user_permanent\Charbel_Assaf\0_NMR_Data\1_NMR400\20230907_1_13C_Pyr_6\Adjusted\"   ;

%%%% complex 2
Files{1}       = "20230907_1_13C_pyr_6_exp26_-14.98_(2)_256K_adjusted.csv"  ;
Files{2}       = "20230907_1_13C_pyr_6_exp126_-14.98_(2)_261K_adjusted.csv" ;
Files{3}       = "20230907_1_13C_pyr_6_exp226_-14.98_(2)_267K_adjusted.csv" ;
Files{4}       = "20230907_1_13C_pyr_6_exp24_-24.09_(2)_256K_adjusted.csv"  ;
Files{5}       = "20230907_1_13C_pyr_6_exp124_-24.09_(2)_261K_adjusted.csv" ;
Files{6}       = "20230907_1_13C_pyr_6_exp224_-24.09_(2)_267K_adjusted.csv" ;
Files{7}       = "20230909_2_13C_pyr_6_exp126_-14.98_(2)_256K_adjusted.csv" ;
Files{8}       = "20230909_2_13C_pyr_6_exp226_-14.98_(2)_261K_adjusted.csv" ;
Files{9}       = "20230909_2_13C_pyr_6_exp326_-14.98_(2)_267K_adjusted.csv" ;
Files{10}      = "20230920_2_13C_pyr_7_exp126_-24.09_(2)_256K_adjusted.csv" ;
Files{11}      = "20230920_2_13C_pyr_7_exp226_-24.09_(2)_261K_adjusted.csv" ;
Files{12}      = "20230909_2_13C_pyr_6_exp326_-24.09_(2)_267K_adjusted.csv" ;


[xdata,ydata, data_lengths]  = combinealldata(Folder,Files)                ;
xdata                        = xdata/1e3                                   ;
%%
%%%%%%%%%%%%%% Fitting all combined data %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Initial parameter guesses
initial_params = [5,   5, 5, ...
                  4,   5, 5, ...
                  3,   4, 5, ...
                  3,   4, 5, ...
                  0.5,   0.1, 0.3, 2.68 ...
                  0.3,   0.6, 0.10]                                        ;
              %A1-3,
              %A4-6,
              %A7-9,
              %A10-12
              %J1-4, 
              %R1-3

%%%%%%%%%%%%%% Define the fitting function %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
fitting_function = @(params, x) Fit_CA_12_SEPP_SPINEPT_nonuniform(params(1), params(2), params(3), ...
                                                      params(4), params(5), params(6), ...
                                                      params(7), params(8), params(9), ...
                                                      params(10), params(11), params(12),...
                                                      params(13), params(14), params(15),params(16),...
                                                      params(17), params(18), params(19),data_lengths, x);

%%%%%%%%%%%%%% Perform the fitting using nlinfit %%%%%%%%%%%%%%%%%%%%%%%%%%
[beta1,R,J,CovB] = nlinfit(xdata, ydata, fitting_function, initial_params) ;

ysim             = fitting_function(beta1,xdata)                           ;
SE               = sqrt(diag(CovB))                                        ;

%%%%%%%%%%%%%%%%%%% Display the fitted parameters %%%%%%%%%%%%%%%%%%%%%%%%%
J1               = beta1(13)                                               ;
J2               = beta1(14)                                               ;
J3               = beta1(15)                                               ;
J4               = beta1(16)                                               ;
R1               = beta1(17)                                               ;
R2               = beta1(18)                                               ;
R3               = beta1(19)                                               ;


disp('Fitted Parameters:')                                                 ;
fprintf('J1 = (%.3f ± %.3f) Hz \n\r',[J1,SE(13)])                          ;
fprintf('J2 = (%.3f ± %.3f) Hz \n\r',[J2,SE(14)])                          ;
fprintf('J3 = (%.3f ± %.3f) Hz \n\r',[J3,SE(15)])                          ;
fprintf('J4 = (%.3f ± %.3f) Hz \n\r',[J4,SE(16)])                          ;
fprintf('R1 = (%.3f ± %.3f) s^-1 \n\r',[R1,SE(17)])                        ;
fprintf('R2 = (%.3f ± %.3f) s^-1 \n\r',[R2,SE(18)])                        ;
fprintf('R3 = (%.3f ± %.3f) s^-1 \n\r',[R3,SE(19)])                        ;


%%%%%%%%%%%%%%%%%% Plotting %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
plotNkinetics_loc(12,xdata,ydata,xdata,ysim,data_lengths)                   ;

%saveas(gcf,'P:\user_permanent\Charbel_Assaf\0_NMR_Data\1_NMR400\20230907_1_13C_Pyr_6\Adjusted\1-13C_[2].png')
toc
%%
%%%%%%%%%%%%%%%%%%Functions%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [xdata, ydata, data_lengths] = combinealldata(Folder, Files)
    num_files = length(Files)                                              ;

    xdata     = []                                                         ;
    ydata     = []                                                         ;
    data_lengths = zeros(1, num_files)                                     ;
 
    for i = 1 : num_files
        loaddata        = load(fullfile(Folder, Files{i}))                 ;
        xdata           = [xdata, loaddata(:, 1)']                         ;                
        ydata           = [ydata, loaddata(:, 2)']                         ;
        data_lengths(i) = length(loaddata(:, 1))                           ;
    end

    xdata   = xdata'                                                       ;
    ydata   = ydata'                                                       ;
end


function RMSD  = plotNkinetics_loc(N,x,y,xsim,ysim,L)
                               
    figure("Color","white",'DefaultAxesFontSize',20,'Position',[700 0 850 2500])
    c = 0                                                                  ;
    for k = 1: N
        subplot(N,1,k)
        plot(x(c+1:c+L(k)),y((c+1:c+L(k))),"LineWidth",2,"Marker","o")
        hold on
        plot(xsim(c+1:c+L(k)),ysim((c+1:c+L(k))),"LineWidth",3.5) ;
        hold off
        
%        xlabel("𝜏_2 (s)",'Fontsize',12)
%        ylabel("Integrals (norm.)")
        axis([-0.1,max(x)+0.2,-0.4,1.1])
        RMSD = rms(y((c+1:c+L(k)))-ysim((c+1:c+L(k))))                     ;
        legend(["Experimental{H}","Fitting"])
        legend('boxoff')
        title(sprintf("RMSD = %.4f",RMSD))                                 ;
        c = c + L(k)                                                       ;
    end
end