%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear all; %clear all and delete all previous data
LoadPath();
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%  Spectroscopy(N=3), Classical Transition approach %%%%%%%%%%%%
tic
System_ID=40;% EFP-38, Eth-Pyruvate-d6-spin2-40, Eth-Acetate-d3-spin2-37
System = Load_System_Name(System_ID);

ex = Load_System(System);
Frequency = 2.430872137983760e+07;
ex.B0=Frequency/(ex.S.gamma{1}/2/pi);
%ex.B0=0.55;%0.55;% Tesla
p90=30e-6;
p180=p90*2;
p45=p90/2;
err=1;
ppmrf=10e-6;
tau=linspace(0,25,1000)*1e-3; % seconds tau, TE=2tau
v1=1/(4*p90);
nechoes = 2000;

SOTs{1}="OPE-45-CPMG-Rn_2D";
SOTs{2}="OPE-45-CPMG-CPRn_2D";

SOT.name=SOTs{2};

H0=2*pi*HZJij(ex.S,ex.PPM,ex.J,ex.B0,"full");
[Q, E]=eig(full(H0));
req=DensityMatrix('100%_SingletSpinOrder',ex.S,ex.n1,ex.n2);%;%initial state
req=req.RemoveCoherences(Q);
 
H1_0=2*pi*HZJij_RF1(ex.S,ex.PPM,ex.J,ex.B0,0,ppmrf,"X",ex.eH);
H1_X=2*pi*HZJij_RF1(ex.S,ex.PPM,ex.J,ex.B0,v1,ppmrf,"X",ex.eH);
H1_Y=2*pi*HZJij_RF1(ex.S,ex.PPM,ex.J,ex.B0,v1,ppmrf,"Y",ex.eH);
[TE,sim.Y12]=OPE_CPMG_2D(SOT,req,tau,nechoes,H0,H1_X,H1_Y,ex.SOs,p45*err,p90*err,p180*err);

%%
sim.name=SOT.name;
sim.System=System;
sim.nechoes=nechoes;
sim.B0=ex.B0;
sim.p90=p90;
sim.p180=p180;
sim.p45=p45;
sim.p_err=err;
sim.ppmrf=ppmrf;
sim.v1=v1;
sim.TE=TE*1e3;
sim.tau=tau;

save('out\sim_'+sim.name+'_'+sim.System+'.mat','sim');

plot_kinetics_2D(sim)
plot_kinetics_totaltime_2D(sim)
toc
%%%%% finish   Spectroscopy(N=3), Classical Transition approach %%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


function plot_kinetics_2D(sim)
    font_small = 13;
    font_large = 15;
    figure('Name','Spectrum','Color','white','NumberTitle','off','DefaultAxesFontSize',font_small);
    ax=axes('Box','on');
    ax.set('FontSize',20,'FontName','Arial','TickDir','out','TickLength',[0.02 0.025],'XMinorTick','on','YMinorTick','on','Box','on','LineWidth',3);
    %colormap("parula");
    colormap("bone");
    [X,Y]=meshgrid(1e3*sim.tau,1:sim.nechoes);
    Z=sim.Y12*1;    
    Z=abs(Z)-min(min(abs(Z)));
    min(min(abs(Z)))
    %sur = surf(X,Y,Z,"EdgeColor","none"); 
    contourf(Y,X,Z,'edgecolor','none')
      
    ylabel("\tau (ms)","FontSize",font_large)
    xlabel("numbe of echoes","FontSize",font_large)
    a=colorbar('Ticks',[0,0.1,0.2,0.3,0.4,0.5]);
    %a=colorbar();
    ylabel(a,'|Polarization per proton|','FontSize',font_large,'Rotation',270);
    a.Label.Position(1) = 3.7;    
    axis([1,50,0,25,-50,50]);    
    view(2)
    drawnow;    
    saveas(gcf,'out\tau_n_'+sim.name+'_'+sim.System+'_image2D.png');
end

function plot_kinetics_totaltime_2D(sim)
    font_small = 13;
    font_large = 15;
    figure('Name','Spectrum','Color','white','NumberTitle','off','DefaultAxesFontSize',font_small);
    %colormap("parula");
    colormap("bone");        
    [X,Y]=meshgrid(1e3*sim.tau,1:sim.nechoes);
    Y=2*(1:sim.nechoes)'*(1e3*sim.tau);
           
    Z=sim.Y12*1;    
    Z=abs(Z)-min(min(abs(Z)));
    min(min(abs(Z)))
    %sur = surf(X,Y,Z,"EdgeColor","none"); 
    contourf(Y,X,Z,'edgecolor','none')
      
    ylabel("\tau (ms)","FontSize",font_large)
    xlabel("2n \tau (ms)","FontSize",font_large)
    a=colorbar('Ticks',[0,0.1,0.2,0.3,0.4,0.5]);
    %a=colorbar();
    ylabel(a,'|Polarization per proton|','FontSize',font_large,'Rotation',270);
    a.Label.Position(1) = 3.7;    
    axis([1,1000,0,25,-50,50]);    
    view(2)
    drawnow;    
    saveas(gcf,'out\tau_totalt_'+sim.name+'_'+sim.System+'_image2D.png');
end

function [TE, Ysum]=OPE_CPMG_2D(SOT,rin,tau,n,H0,H1_X,H1_Y,SOs,p45,p90,p180)    
    Ysum=zeros(n,length(tau));
    out=zeros(n,length(SOs));
    TE = (1:n)'*2*tau;
    for nt=1:length(tau)
        if mod(nt,10)==0
            nt/length(tau)*100
        end
        t_evol=tau(nt);

        [t,A,r0]=rin.EvolutionConstH(H1_Y,p45,[]); %rotation             
        r1=r0;        
        switch SOT.name
            case "OPE-45-CPMG-Rn_2D"                                                                       
                for in=1:n
                    [t,A,r1]=r1.EvolutionConstH(H0,t_evol,[]);  

                    [t,A,r1]=r1.EvolutionConstH(H1_Y,p180,[]); %rotation                

                    [t,A,r1]=r1.EvolutionConstH(H0,t_evol,[]);        
                    out(in,:)=real(r1.Amplitudes(SOs));
                end 

            case "OPE-45-CPMG-CPRn_2D"        
                for in=1:n
                    [t,A,r1]=r1.EvolutionConstH(H0,t_evol,[]);  

                    [t,A,r1]=r1.EvolutionConstH(H1_X,p90,[]); %rotation 
                    [t,A,r1]=r1.EvolutionConstH(H1_Y,p180,[]); %rotation
                    [t,A,r1]=r1.EvolutionConstH(H1_X,p90,[]); %rotation 

                    [t,A,r1]=r1.EvolutionConstH(H0,t_evol,[]); 
                    out(in,:)=real(r1.Amplitudes(SOs));
                end                                                                          
        end   
        
        Ysum(:,nt)=(out(:,3)+out(:,4))/2;
    end
end



