clear all
close all 
tic
p = LoadPath('CA')                                                         ;


%%
%%%%%%%%%%%%%%%%%%%%%% Load all data  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Folder         = "IrHH_data\kd_IrHH_pyr_[3]\"   ;

Files{1}       = "kd_IrHH_Ha_pyr_174mM_[3].txt"                      ;
Files{2}       = "kd_IrHH_Hb_pyr_174mM_[3].txt"                      ;

% Choosing the fitting Model 

Model_types{1} = 'IrH’H↔H2'                                               ;
Model_types{2} = 'IrH’H↔H2_alpha'                                         ; % with correction of second set to enhance fitting

Model_type     = Model_types  {2}                                          ; % choose the Fitting Model

% Initial parameter guesses
I = [7,   1,  ...
    1,   1,  ...
    1,   1,    ]                                         ;
              
%% %%%%%%%%%%%% Fitting all combined data %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
switch Model_type
         
       case 'IrH’H↔H2'      
           
       alpha     =       1                                                 ; % Enhancing factor of the data it also could be 1/ max (y.Hb(max)) 
       [xdata,ydata, data_lengths]  = combinealldata(Folder,Files,alpha)   ;
      
       MHa1 = 1    ;   MHb1 = ydata(30)       ;   MH21 = 0                 ;
       MHa2 = 1    ;   MHb2 = ydata(117)      ;   MH22 = MH21              ;
       
fitting_function = @(params, x) Fit_CA_2_SEPP_SABRE_nonuniform( MHa1, MHb1,   MH21, MHa2,   MHb2, MH22, ...
                                                                 params(1),    params(2),     ...
                                                                 params(3),    params(4),     ...
                                                                 params(5),    params(6), data_lengths, x); % (MHa1,MHb1,MH21,MHa2,MHb2,MH22,kd,kex,kaprime,RHa,RHb,RH2,L, x)           
           
       case 'IrH’H↔H2_alpha'    
       alpha     =       3                                                 ; % Enhancing factor of the data it also could be 1/ max (y.Hb(max)) 
       [xdata,ydata, data_lengths]  = combinealldata(Folder,Files,alpha)   ;
      
       MHa1 = 1    ;   MHb1 = ydata(30)       ;   MH21 = 0                 ;
       MHa2 = 1    ;   MHb2 = ydata(117)      ;   MH22 = MH21              ;
       
fitting_function = @(params, x) Fit_CA_2_SEPP_SABRE_nonuniform_alpha( MHa1, MHb1,   MH21, MHa2,   MHb2, MH22, ...
                                                                 params(1),    params(2),     ...
                                                                 params(3),    params(4),     ...
                                                                 params(5),    params(6),data_lengths, x,alpha); % (MHa1,MHb1,MH21,MHa2,MHb2,MH22,kd,kex,kaprime,RHa,RHb,RH2,L, x)  

end 

%% %%%%%%%%%%%%%% Perform the fitting using nlinfit %%%%%%%%%%%%%%%%%%%%%%%
[beta1,R,J,CovB]  = nlinfit(xdata, ydata, fitting_function, I);

ysim              = fitting_function(beta1,xdata)                          ;
SE                = sqrt(diag(CovB))                                       ;

%%%%%%%%%%%%%%%%%%% Display the fitted parameters %%%%%%%%%%%%%%%%%%%%%%%%%
kd                = beta1(1)                                               ;
kex               = beta1(2)                                               ;
kaprime           = beta1(3)                                               ;
RHa               = beta1(4)                                               ;
RHb               = beta1(5)                                               ;
RH2               = beta1(6)                                               ;

disp('Fitted Parameters:')                                                 ;
fprintf('kd  = %.3f ± %.3f s^-1 \n\r',[kd,SE(1)])                          ;
fprintf('kex = %.3f ± %.3f s^-1 \n\r',[kex,SE(2)])                         ;
fprintf('kaprime = %.3f ± %.3f s^-1 \n\r',[kaprime,SE(3)])                 ;
fprintf('RH2 = %.3f ± %.3f s^-1 \n\r',[RH2,SE(6)])                         ;
fprintf('RHa = %.3f ± %.3f s^-1 \n\r',[RHa,SE(4)])                         ;
fprintf('RHb = %.3f ± %.3f s^-1 \n\r',[RHb,SE(5)])                         ;

%%
% %% fitting without kaprime 
% % Initial parameter guesses
% initial_params = [0.4,   1,  ...
%                   1,   0.8,  ...
%                   0.2,       ]                                           ;
%               
% MHa1 = 1    ;   MHb1 = ydata(30)       ;   MH21 = 0        ; Ir = 4       ;
% MHa2 = 1    ;   MHb2 = ydata(117)      ;   MH22 = MH21     ; H2 = 1.14678 ;
% 
% %%%%%%%%%%%%%% Define the fitting function %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% fitting_function = @(params, x) Fit_CA_2_SEPP_SABRE( MHa1, MHb1,   MH21, MHa2,   MHb2, MH22, Ir, H2 , ...
%                                                                     params(1),    params(2),          ...
%                                                                     params(3),    params(4),          ...
%                                                                     params(5),    data_lengths, x        ); % (MHa1,MHb1,MH21,MHa2,MHb2,MH22,Ir, H2 ,kd,kex,RHa,RHb,RH2,L, x)
% 
% %%%%%%%%%%%%%% Perform the fitting using nlinfit %%%%%%%%%%%%%%%%%%%%%%%%%%
% [beta2,R,J,CovB] = nlinfit(xdata, ydata, fitting_function, initial_params) ;
% 
% ysim2            = fitting_function(beta2,xdata)                           ;
% SE               = sqrt(diag(CovB))                                        ;
% 
% %%%%%%%%%%%%%%%%%%% Display the fitted parameters %%%%%%%%%%%%%%%%%%%%%%%%%
% kd                = beta2(1)                                               ;
% kex               = beta2(2)                                               ;
% RHa               = beta2(3)                                               ;
% RHb               = beta2(4)                                               ;
% RH2               = beta2(5)                                               ;
% 
% disp('Fitted Parameters:')                                                 ;
% fprintf('kd2  = %.3f ± %.3f s^-1 \n\r',[kd,SE(1)])                         ;
% fprintf('kex2 = %.3f ± %.3f s^-1 \n\r',[kex,SE(2)])                        ;
% fprintf('RH22 = %.3f ± %.3f s^-1 \n\r',[RH2,SE(5)])                        ;
% fprintf('RHa2 = %.3f ± %.3f s^-1 \n\r',[RHa,SE(3)])                        ;
% fprintf('RHb2 = %.3f ± %.3f s^-1 \n\r',[RHb,SE(4)])                        ;


%% 
 
%%%%%%%%%%%%%%%%%% Plotting %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
plotNkinetics_loc(2,xdata,ydata,xdata,ysim,data_lengths,alpha)             ;
%plotNkinetics_loc(2,xdata,ydata,xdata,ysim2,data_lengths)                  ;


%%%%%%%%%%%% Increasing the number of the fitting points %%%%%%%%%%%%%%%%%%


x_fit                     = logspace(log10(min(xdata)),log10(max(xdata)),100)' ;
x_fit_fit                 = reshape(x_fit*[1,1,1,1,1,1],6*length(x_fit),1)     ;
data_lengths              = [300, 300]                                         ;

y_fit = Fit_CA_2_SEPP_SABRE_nonuniform_alpha( MHa1, MHb1,   MH21, MHa2,   MHb2, MH22, ...
                                                                 beta1(1),    beta1(2),     ...
                                                                 beta1(3),    beta1(4),     ...
                                                                 beta1(5),    beta1(6), data_lengths , x_fit_fit,alpha);

% y_fit2 = Fit_CA_2_SEPP_SABRE(MHa1, MHb1,   MH21, MHa2,   MHb2, MH22, Ir, H2 , ...
%                                                                  beta2(1),     beta2(2),     ...
%                                                                  beta2(3),     beta2(4),     ...
%                                                                  beta2(5),     data_lengths , x_fit_fit   ); % (MHa1,MHb1,MH21,MHa2,MHb2,MH22,Ir, H2 ,kd,kex,RHa,RHb,RH2,L, x)                                                             

% PAPER = [x_fit, y_fit(1:100),y_fit(101:200),y_fit(201:300),y_fit(301:400),y_fit(401:500),y_fit(501:600)];

%saveas(gcf,'P:\user_permanent\Charbel_Assaf\0_NMR_Data\1_NMR400\20230909_2_13C_Pyr_6\Adjusted\2-13C_[2].png')
toc
%%
%%%%%%%%%%%%%%%%%%Functions%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


function [xdata, ydata, data_lengths] = combinealldata(Folder, Files,alpha)
                            num_files = length(Files)                      ;

                            xdata     = []                                 ;
                            ydata     = []                                 ;
                         data_lengths = zeros(1, num_files)                ;

    for i = 1: num_files
        loaddata        = load(fullfile(Folder, Files{i}))                 ;
        xdata           = [xdata, loaddata(:, 1)',loaddata(:, 1)',loaddata(:, 1)'] ;                
        ydata           = [ydata, loaddata(:, 2)',alpha*loaddata(:, 3)',loaddata(:, 4)'] ;
        data_lengths(i) = 3*length(loaddata(:, 1))                         ;
    end

    xdata = xdata'                                                         ;
    ydata = ydata'                                                         ;
end

function RMSD  = plotNkinetics_loc(N,x,y,xsim,ysim,L,alpha)
                               
    figure("Color","white",'DefaultAxesFontSize',20,'Position',[700 0 850 800])
    c = 0                                                                  ;
    for k = 1:N
        subplot(N,1,k)
        semilogx(x(c+1:c+L(k)/3),y((c+1:c+L(k)/3)),"oblack",x(c+1:c+L(k)/3),y((c+1+L(k)/3:c+2*L(k)/3))/alpha,"or",x(c+1:c+L(k)/3),y((c+1+2*L(k)/3:c+L(k))),"ob")
        hold on
        semilogx(xsim(c+1:c+L(k)/3),ysim((c+1:c+L(k)/3)),"black",xsim(c+1:c+L(k)/3),ysim((c+1+L(k)/3:c+2*L(k)/3))/alpha,"red",xsim(c+1:c+L(k)/3),ysim((c+1+2*L(k)/3:c+L(k))),"blue","LineWidth",2) ;
        hold off
        
        xlabel("𝜏_e (s)",'Fontsize',22)
        ylabel("Integrals (norm.)")
        axis([0.001,max(x)+10,-0.5,1.1])
        RMSD = rms(y((c+1:c+L(k)))-ysim((c+1:c+L(k))))                     ;
        legend({"H_a","H_b","H_2","Fitting","Fitting","Fitting"})
        legend('boxoff')
%        title(sprintf("RMSD = %.4f",RMSD))                                 ;
        c = c + L(k)                                                       ;
    end
end