%% start %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear all; %clear all and delete all previous data
tic
p=LoadPath();
%% change parameters here
JAX=2; % AX spin coupling
spec.Relaxation = "Off"; % "Off" or "DD", "LFF"
%pAX_XZZ = 0.4; % polarization of the spin AX XZZ-spin order
B0 = My_sph2cart(0, 45, 40*1e-9) % X=0,0, Y=90,0, Z=0,90 fields in [T]
spec.RX = My_sph2cart(0 , 0, 1) % X=0,0,1 Y=90,0,1 Z=0,90,1 observation direction r=1
%ex.B0 = [0,1,10,20,50,100,400,1000]*1e-9; % [T] % observation fields
spec.R2=1/5; % phenomenological 1/T2* = [s-1]
spec.SW=40  ; % spectral width [Hz]
spec.TD=1024*8 ; % spectral width and number of points in FID  
Folder = "out\SHEATH_SABRE_spectrum";
%% Load System %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
System=Load_System_Name(55); %AX is system 44 %A2X is system 45; %A3X is system 46 % A3XX 51  % A(1Hspin1)X 49     % A(1Hspin3/2)X 50
ex=Load_System(System,JAX);
ex.Folder=Folder+System+"_.mat";
%% calculate pulsed SABRE%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%r0 = get_initial_state(12,ex);
% Initial state: 
%InSt = "from_file"
InSt = "artificial";
switch InSt
    case "artificial"
        pA = My_sph2cart(0, 0, 0.5) % X=0,0, Y=90,0, Z=0,90 polarization vector of spins A        
        pX = My_sph2cart(180, 0, 1) % X=0,0, Y=90,0, Z=0,90 polarization vector of spins X
        pAX_ZZ = 0; 
        pAX_ZZZ = 0*20; 
        r0   = DensityMatrix(ex.S.U + (pA(1)*ex.S.Dir("X",1:ex.S.N-ex.NX)/(ex.S.SpinVal{1}+1) + pX(1)*ex.S.Dir("X",ex.S.N-ex.NX:ex.S.N)/(ex.S.SpinVal{end}+1))*3/ex.S.Nstates+...
                                      (pA(2)*ex.S.Dir("Y",1:ex.S.N-ex.NX)/(ex.S.SpinVal{1}+1) + pX(2)*ex.S.Dir("Y",ex.S.N-ex.NX:ex.S.N)/(ex.S.SpinVal{end}+1))*3/ex.S.Nstates+...
                                      (pA(3)*ex.S.Dir("Z",1:ex.S.N-ex.NX)/(ex.S.SpinVal{1}+1) + pX(3)*ex.S.Dir("Z",ex.S.N-ex.NX:ex.S.N)/(ex.S.SpinVal{end}+1))*3/ex.S.Nstates);

        % add this term if you need to add other spin orders
        % r0.val=r0.val+pAX_ZZ*ex.S.Dir("Z",ex.S.N)*ex.S.Dir("Z",1:3)*9/((ex.S.SpinVal{1}+1)*(ex.S.SpinVal{end}+1)*ex.S.Nstates);
        %r0.val=r0.val+pAX_ZZZ*ex.S.Dir("Z",ex.S.N)*(ex.S.Dir("Z",1)*ex.S.Dir("Z",2)+ex.S.Dir("Z",2)*ex.S.Dir("Z",3)+ex.S.Dir("Z",3)*ex.S.Dir("Z",1))*27/((ex.S.SpinVal{1}+1)*(ex.S.SpinVal{2}+1)*(ex.S.SpinVal{end}+1)*ex.S.Nstates);
    case "from_file"
        in=load("out\SABRESHEATH_HH-2C-Pyruvate_B400nT_Kd1.mat");
        r6=in.ex.Yout.rC;
        S6=in.ex.Sc;
        r0=r6.trace2First(S6);
        r0.ShowOperators(ex.S,1e-4);        
        %r0=r0.RotationSuperOperator(pi/2,'Y',ex.S,1:4);       
end


%% spectrum parameters
ex.B0=B0; 
spec.Excitation.Spins = []; % excited spins            not used
spec.Excitation.Phase = 'X'; % excited spins           not used
spec.Excitation.Pulse = pi/2; % excitation pulse [rad] not used
if length(ex.B0(:,1))==1
    %% calculate 1 1D spectrum
    spec.B0=ex.B0 ;               % observation magnetic field [T]    
    [spec] = Spectrum_1D(ex,r0,spec);
    % plot spectrum
    types_spec{1}="relative FRQ";
    types_spec{2}="absolute FRQ";
    %%
    spec.axis = [0 25];
    plot_xyz_spectra(System,ex,spec,types_spec{2});    
else
    %% calculate Many 1D spectra
    All_specs=zeros(spec.TD,length(ex.B0));
    for ib=1:length(ex.B0)
        spec.B0=ex.B0(ib) ;               % observation magnetic field [T]    
        [spec] = Spectrum_1D(ex,r0,spec);
        All_specs(:,ib)=spec.spec;
    end       
    z = (real(All_specs));
    x = spec.FRQ;
    y = ex.B0*1e9;
    figure("color","white")        
    s=stackedplot(x,z);
    s.DisplayLabels=num2cell(y);
    axis([0,300,0,max(z)]);
    ylabel("Magnetic field (nT)");
    xlabel("Frequency (Hz)");
end


%%%%%%%%%%%%%%%%%%%%%%%%%% end %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
toc

function V = My_sph2cart(azimuth, elevation, r)
% azimuth is the counterclockwise angle in the xy plane measured from the positive x axis.  
% elevation is the elevation angle from the xy plane.
% both are in degrees
 [x,y,z] = sph2cart(azimuth/180*pi, elevation/180*pi,r);
 V=[x,y,z];
end
