% this script compares several similutaions which have different Kd (dissociation rate) 
% with an experimental results to know the dissociation rate of the experiment.

clear all; %clear all and delete all previous data
%close all
tic
p = LoadPath();

%% Name of the folder which contains the simulations files %%%%%%%%%%%%%%%% 
System_type{1} = "HHN-1"     ;
System_type{2} = "HHNN-2"    ;
System_type{3} = "HHC-1"     ;
System_type{4} = "HHHC-1"    ;
System_type{5} = "HH-HHHC-1" ;

INEPT_types{1} = 'SABREINEPT'                 ;
INEPT_types{2} = 'SABREINEPT_Multi_Kd'        ;
INEPT_types{3} = 'SABREINEPTplus'             ;
INEPT_types{4} = 'SABREINEPTplus_Multi_Kd'    ;
INEPT_types{5} = 'SABREINEPT2'                ;
INEPT_types{6} = 'SABREINEPT2_Multi_Kd'       ;

System     = System_type{2}    ;
INEPT_type = INEPT_types{4}    ; 
ex.Folder  = "out\"+System+"\INEPT\"+INEPT_type+"\"+INEPT_type+"_"            ; % 

%% Load data of the experimental file %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ex.experiment = "expdata\"+System+"\INEPT\"+INEPT_type+"\"                              ; 
temp          = 293                                                                ;
data_in       = load(ex.experiment+'SABREPy_INEPTplus_'+temp'+'K_adjusted.csv','-ASCII')    ; % change the name in line 100

data.tau      = data_in(:,1)             ;
data.amp      = data_in(:,2)             ;

%% Calculating difference between the experimental data and the simulation data 
Kd_range   = 8:0.1:60                                  ; %9:0.1:51
coefficients          = 0.5:0.1:10                     ;
RMSE = zeros(length(Kd_range),1)                       ;
minimumcoefficients        = zeros(length(Kd_range),1) ;
for ik = 1:length(Kd_range)
    ik/length(Kd_range)*100
    tempsimulation = load(ex.Folder+Kd_range(ik)+'.csv','out')   ; % temporarily 
    x = tempsimulation(:,1)                                      ; % tau of each simulation
     switch INEPT_type
     case {'SABREINEPT','SABREINEPT_Multi_Kd','SABREINEPT2','SABREINEPT2_Multi_Kd'}
          y = tempsimulation(:,2)                                ; % amp of each simulation 
     case {'SABREINEPTplus','SABREINEPTplus_Multi_Kd'}
          y = -tempsimulation(:,2)                               ; % amp of each simulation 
     end
    ynorm  = y(:,1)/max(y(:,1))                                  ; % normalized amp 
    for kk = 1:length(coefficients)
     diff   = (data.amp - coefficients.*ynorm)                   ; % diff   = x-xi 
     power2 = diff.^2                                            ; % power2 = (x-xi)^2
     average  = sqrt(mean(power2))                               ; % RMSE   
     [minv, ind] = min(average, [], 'all', 'linear')             ;
    end
    RMSE (ik) = minv;
    minimumcoefficients (ik) = coefficients(ind); 
end

%% finding the closest simulation %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
[X, ind] = min(RMSE, [], 'all', 'linear')  ;
disp(ex.Folder+Kd_range(ind)+'.csv','out')
coefficient = minimumcoefficients(ind)     ;

%% load similar simulation of the experimental results %%%%%%%%%%%%%%%%%%%%
Simulation                = load(ex.Folder+Kd_range(ind)+'.csv','out','-ASCII')       ;
SimilarSimulation.tau     = Simulation(:,1)                                           ; % tau of the similar simulation 
     switch INEPT_type
         case {'SABREINEPT','SABREINEPT_Multi_Kd','SABREINEPT2','SABREINEPT2_Multi_Kd'}   
                SimilarSimulation.amp     = Simulation(:,2)                           ; % amp of the similar simulation 
         case {'SABREINEPTplus','SABREINEPTplus_Multi_Kd'}    
                SimilarSimulation.amp     = -Simulation(:,2)                          ; % amp of the similar simulation 
     end 
SimilarSimulation.normamp = SimilarSimulation.amp(:,1)/max(SimilarSimulation.amp(:,1)); % normalized amp of the similar simulation
%% plot the experimental and the similar simulation %%%%%%%%%%%%%%%%%%%%%%% 
figure;
set(gcf,'color','w')                                  ;
subplot(1,2,1)
plot(1e3*data.tau, data.amp,'r','LineWidth',2)        ;
hold on 
plot(1e3*SimilarSimulation.tau, coefficient*SimilarSimulation.normamp,'b','LineWidth',2);
xlabel('Tau (ms)')                                    ;
ylabel('Amplitude')                                   ;
legend('experimental signal','simulation signal')     ;
title(sprintf("k_d = %.2f s^{-1} & coefficient = %.2f ",[Kd_range(ind),coefficient]))
grid on 

subplot(1,2,2)
plot(Kd_range, RMSE,'b','LineWidth',2)                 ;
xlabel('K_d (s^-^1)')                                  ;
ylabel('RMSE')                                         ;
xlim([0  62])
title('Root Mean Square Error for all K_d')
grid on 

%% plotting dissociation rate Kd in fonction of temperature %%%%%%%%%%%%%%%
% figure; for SABREINEPT
% set(gcf,'color','w')                                   ;
% Xtemp = [ 280    , 283    , 288    , 293    ]          ;
% YKd   = [ 15.44  , 20.29  , 33.52  , 28.25  ]          ;
% error = [ 0.941  , 1.339  , 2.097  , 0.572  ]          ;
% errorbar(Xtemp,YKd ,error,'vertical','o')              ;
%       
% xlim([270  300])                                       ;
% ylim([14 36])                                          ;
% xlabel('Temperature')                                  ;
% ylabel('K_d (s^-^1)')                                  ;
% title ('K_d in fonction of temperature')

% outRMSE = [Kd_range', RMSE];
% stdd = std (RMSE);
% save("expdata\SABREPy_INEPT_288K_RMSE.csv","outRMSE",'-ASCII')
 %% Save the similar simulation with the coefficient %%%%%%%%%%%%%%%%%%%%%%%
% out = [SimilarSimulation.tau ,coefficient*SimilarSimulation.normamp];
% save("expdata\SABREPy_INEPT_"+temp+"K_simulation.csv","out",'-ASCII') % change the name 
% toc

