% change INEPT_type line 24
% Change temp value 280, 283, 288, 293 line 28
clear all  % clear all and delete all previous data
close all
tic
p = LoadPath();
%% Name of the folder which contains the simulations files %%%%%%%%%%%%%%%% 
System_type{1} = "HHN-1"     ;
System_type{2} = "HHNN-2"    ;
System_type{3} = "HHC-1"     ;
System_type{4} = "HHHC-1"    ;
System_type{5} = "HH-HHHC-1" ;

INEPT_types{1} = 'SABREINEPT'                 ;
INEPT_types{2} = 'SABREINEPT_Multi_Kd'        ;
INEPT_types{3} = 'SABREINEPTplus'             ;
INEPT_types{4} = 'SABREINEPTplus_Multi_Kd'    ;
INEPT_types{5} = 'SABREINEPT2'                ;
INEPT_types{6} = 'SABREINEPT2_Multi_Kd'       ;
INEPT_types{7} = 'SABREINEPT2tev'             ;
INEPT_types{8} = 'SABREINEPT2tev_Multi_Kd'    ;

System     = System_type{2}    ;
INEPT_type = INEPT_types{8}    ; 
%ex.Folder  = "out\"+System+"\"+INEPT_type+"\"+INEPT_type+"_"            ; % 
%% Load data of the experimental file %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ex.experiment = "expdata\"+System+"\"+INEPT_type+"\"                              ;
temp          = 283                                                              ;
data_in       = load(ex.experiment+'SABREINEPT_'+temp+'K_adjusted.csv','-ASCII')    ; % change the name in line 100

data.tau      = data_in(:,1);
switch INEPT_type
         case 'SABREINEPT_Multi_Kd' 
                data.amp     = data_in(:,2)                    ;
         case 'SABREINEPTplus_Multi_Kd'   
                data.famp    = data_in(:,2)                    ;
                data.amp     = data.famp - (min(data.famp))    ;
         case 'SABREINEPT2tev_Multi_Kd'
                data.famp    = data_in(:,2)/max(data_in(:,2))  ;
                data.amp     = data.famp ;% - (min(data.famp))    ;
end 

fo = fitoptions('Method','NonlinearLeastSquares',...
               'Lower',[0,0],...
               'Upper',[Inf,70],...
               'DiffMinChange',0.1,...
               'StartPoint',[0 19]); 
myexp       = fittype('Load_INEPT_simulation(A,B,x)','coefficients',{'A','B'},'independent',{'x'},'dependent',{'y'})  ; 

x=data.tau;
y=data.amp;

[result gof]= fit(x,y,myexp,fo)           ; % goodness-of-fit statistics to the structure gof
coef        = coeffvalues(result)         ; % extracting coefficients 
int         = confint(result)             ; % extracting trusting interval for 95% confidence = 2 sigma
meanerror   = abs((int(2,:)-int(1,:))/4)  ; % 1 sigma


A = coef(1,1)    ;
B = coef(1,2)    ;

disp(sprintf('A = %.3f ± %.3f',[A,meanerror(1)]))                    ;
disp(sprintf('Kd = %.3f ± %.3f s^{-1}',[B,meanerror(2)]))            ;
yfitted = Load_INEPT_simulation(A,B,x)                               ;

figure
set(gcf,'color','w')                                                 ; 
    switch INEPT_type
          case {'SABREINEPT_Multi_Kd','SABREINEPTplus_Multi_Kd'}
               plot(x, y,'b','LineWidth',2)
               hold on 
               plot(x, yfitted,'r','LineWidth',2)                    ;
          case 'SABREINEPT2tev_Multi_Kd'
               semilogx(x, y,'b','LineWidth',2)
               hold on 
               semilogx(x, yfitted,'r','LineWidth',2)                ;
    end
legend('experimental signal','simulation signal')     ;
xlabel('Tau (s)')                                     ;
ylabel('Normalized Amplitude')                        ;
title(sprintf('At temperature %dK  Kd = %.2f ± %.2f s^{-1}',[temp,B,meanerror(2)])) 

% out = [x,y, yfitted];
% save("simulation12 signal.csv","out",'-ASCII')
toc