% 


%variable parameters:
pH = 0:0.1:14;
k2=1e9 ;  % [1/s] 1e13/2

% fixed parameters or parameters of the system
pKa = 3.2;
k1 = 10^(pKa)*k2;  % [1/(s*mol/L)] % 1e18
v0 = 400/10; % [MHz] magnetic field
PPM0=250; % ppm zero offset frequency
Wnam=2*pi*(298-PPM0)*v0; % [rad/s] 100 ppm 15N at 9.4 T;
Whnam=2*pi*(204.5-PPM0)*v0; % [rad/s]
R2=2;



%% experimental chemical shifts as a function of pH

pH_Ex = [0.45	2.67	3.9	4.45	6.47	7.87	9.69	13.46];
PPM_Ex = [203.7	227.6	279.8	294.6	298.3	298.1	298.2	298.2];


Spec_max.A=zeros(1,length(pH));
Spec_max.Frq=zeros(1,length(pH));

for ipH = 1: length( pH)
    ipH
    H = 10^(-pH(ipH));
    [PPM,Spec] = ExAB_spectrum(Wnam,Whnam,R2,k1,k2,H,v0,PPM0);
    [Spec_max.A(ipH), n] = max(abs(Spec));
    Spec_max.Frq(ipH) = PPM(n);    
end
Spec_max.pH=pH
save('Spec_max.mat','Spec_max')

%%
figure('color','white')
subplot(2,1,1)
plot(pH_Ex, PPM_Ex, "o");
hold on
plot(pH,Spec_max.Frq)
xlabel('pH');
ylabel('chemical shift ppm');
subplot(2,1,2)
plot(pH,Spec_max.A)
xlabel('pH');
ylabel('amplitude (a.u.)');




