function ex = LoadSystem(name)

    switch name
        case "HHN-1"
        ex.Sc = SpinOperators(3,{'1H','1H','15N'}); %Ir-complex
        ex.Sh = SpinOperators(2,{'1H','1H'      }); %dihydrogen (pH2)
        ex.Ss = SpinOperators(1,{          '15N'}); %substrate (S2)

        % system
        ex.T1C=[1,1,6];                        % T1 relaxation in the complex, s
        ex.T1S=[60];                           % T1 relaxation in the free substrate, s
        ex.ppmC=[-22 -22 0]*1e-6;              % chemical shift ppm*1e-6 in complex
        ex.ppmS=[100 100]*1e-6;                % chemical shift ppm*1e-6 in substrate
        ex.JC=zeros(ex.Sc.N); % J - coupling in [Hz]
        ex.JC(1,2)=-8; ex.JC(1,3)=-24;
                    ex.JC(2,3)=0;
        ex.JC=ex.JC+ex.JC';
        ex.JS=zeros(ex.Ss.N); % J - coupling in [Hz]
        ex.JS=ex.JS+ex.JS';
        
        % calculate amplitudes for the following spin orders of Ir-complex
        ex.SOc={ex.Sc.SSnorm(1,2),...
                ex.Sc.norm2('z',1,'z',2),ex.Sc.norm2('z',1,'z',3),ex.Sc.norm2('z',2,'z',3),...
                ex.Sc.norm('z',1),       ex.Sc.norm('z',2),       ex.Sc.norm('z',3)};
        ex.SOcStr={'S12',...
                '1Z2Z','1Z3Z','2Z3Z',...
                '1Z','2Z','3Z'};
        % and the substrate
        ex.SOs={ex.Ss.norm('x',1),ex.Ss.norm('y',1),ex.Ss.norm('z',1)};
        ex.SOsStr={'1X','1Y','1Z'};
        
        case "HHNN-2"
        ex.Sc = SpinOperators(4,{'1H','1H','15N','15N'}); %Ir-complex
        ex.Sh = SpinOperators(2,{'1H','1H'            }); %dihydrogen (pH2)
        ex.Ss = SpinOperators(2,{          '15N','15N'}); %substrate (S2)

        % system
        ex.T1C=[1,1,6,6];                        % T1 relaxation in the complex, s
        ex.T1S=[60,60];                           % T1 relaxation in the free substrate, s
        ex.ppmC=[-22 -22 0 0]*1e-6;              % chemical shift ppm*1e-6 in complex
        ex.ppmS=[100 100]*1e-6;                % chemical shift ppm*1e-6 in substrate
        ex.JC=zeros(ex.Sc.N); % J - coupling in [Hz]
        JNH=-24;
        ex.JC(1,2)=-8; 
        ex.JC(1,3)=JNH; ex.JC(2,3)=000;
        ex.JC(1,4)=000; ex.JC(2,4)=JNH; ex.JC(3,4)=000;
        
        
        ex.JC=ex.JC+ex.JC';
        ex.JS=zeros(ex.Ss.N); % J - coupling in [Hz]
        ex.JS=ex.JS+ex.JS';
        
        % calculate amplitudes for the following spin orders of Ir-complex
        ex.SOc={ex.Sc.SSnorm(1,2),...
                ex.Sc.norm('z',1),       ex.Sc.norm('z',2),       ex.Sc.norm('z',3),       ex.Sc.norm('z',4)};
        ex.SOcStr={'S12',...                
                '1Z','2Z','3Z','4Z'};
        % and the substrate
        ex.SOs={ex.Ss.norm('x',1),ex.Ss.norm('y',1),ex.Ss.norm('z',1),ex.Ss.norm('x',2),ex.Ss.norm('y',2),ex.Ss.norm('z',2)};
        ex.SOsStr={'1X','1Y','1Z','2X','2Y','2Z'};
        
        
        otherwise
            disp("error, no such system");

    end
end

