function r = get_initial_state(ID,ex)
    initial_states{1} = '100%_Magnetization' ;    
    initial_states{2} = 'phINEPT'            ;
    initial_states{3} = 'phINEPTplus'        ;
    initial_states{4} = 'SABREINEPT'         ;
    initial_states{5} = 'C1Z3Y+C2Z3Y'        ;
    initial_states{6} = 'C1Z3Y'              ;
    initial_states{7} = 'C1Z+C2Z'            ;
    initial_states{8} = 'C3X+C4X'            ;    
    initial_states{9} = 'all_Y'              ; 
    initial_states{10}= 'Esotheric_SOT'      ;
    initial_states{11}= 'Esotheric_Te_SOT'   ;
    initial_states{12} = 'last_X'            ; 
    initial_states{13} = 'last_Y'            ; 
    initial_states{14} = 'last_Z'            ; 
    initial_state     = initial_states{ID}    ; % choose the initial state of the system

    switch initial_state
        case 'phINEPT'
            Yout = sabre_inept_SOT(ex);  
            rS   = Yout.rS;
            rC   = Yout.rC;
        case 'phINEPTplus'
            Yout = sabre_ineptplus_SOT(ex);  
            rS   = Yout.rS;
            rC   = Yout.rC; 
        case 'SABREINEPT'
            ex.taugrad = 0.002                               ;
            Yout = sabre_inept2tev_SOT(ex);  % sabre_inept2_SOT
            rS   = Yout.rS;
            rC   = Yout.rC;
        case 'C1Z3Y+C2Z3Y'  
            rC   = DensityMatrix(ex.Sc.U + ex.Sc.norm2('z',1,'y',3) + ex.Sc.norm2('z',2,'y',3));%ex.Sc.norm2)+ ex.Sc.norm2('z',2,'y',3)
            rS   = DensityMatrix(ex.Ss.U);
        case 'C1Z3Y'  
            rC   = DensityMatrix(ex.Sc.U + ex.Sc.norm2('z',1,'y',3))                 ; % ex.Sc.norm2('z',2,'y',3)
            rS   = DensityMatrix(ex.Ss.U);
        case 'C1Z+C2Z'  
            rC   = DensityMatrix(ex.Sc.U + + ex.Sc.norm('z',1) + ex.Sc.norm('z',2))  ; % ex.Sc.norm2('z',2,'y',3)
            rS   = DensityMatrix(ex.Ss.U);
        case 'C3XC4X'  
            rC   = DensityMatrix(ex.Sc.U + ex.Sc.norm('x',3) + ex.Sc.norm('x',4))    ; % ex.Sc.norm2('z',2,'y',3)
            rS   = DensityMatrix(ex.Ss.U)                        ;
        case '100%_Magnetization'  
            r   = DensityMatrix('100%_Magnetization',ex.S)       ;            
        case 'all_Y'  
            r   = DensityMatrix(ex.S.U + ex.S.Dir("Y",1:ex.S.N)) ;            
        case 'last_X'  
            r   = DensityMatrix(ex.S.U + (1*ex.S.Dir("X",1:ex.S.N-1) - ex.S.Dir("X",ex.S.N))  ) ; 
        case 'last_Y'  
            r   = DensityMatrix(ex.S.U + ex.S.Dir("Y",1:ex.S.N-1) - ex.S.Dir("Y",ex.S.N)) ;            
        case 'last_Z'  
            r   = DensityMatrix(ex.S.U + ex.S.Dir("Z",1:ex.S.N-1) - ex.S.Dir("Z",ex.S.N)) ; 
            
            
        case 'Esotheric_SOT'
            Yout       = sabre_Esotheric_SOT(ex)                 ;   
            rS         = Yout.rS                                 ;
            rC         = Yout.rC                                 ;
        case 'Esotheric_Te_SOT'
            ex.taugrad = 0.002                                   ;
            Yout       = sabre_Esotheric_Te_SOT(ex)              ;  
            rS         = Yout.rS                                 ;
            rC         = Yout.rC                                 ;
    end
    r.ShowOperators(ex.S,1e-4);
end