function Yout = sabre_ADAPT_RFt(ex)
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %% nonpolorized initial spin state of the Ir-complex and substrate
    rC0=DensityMatrix(ex.Sc.U);
    rS0=DensityMatrix(ex.Ss.U);
    rS=rS0;
    rC=rC0;
            
    NS2=ex.Ss.Nstates^2;
    NC2=ex.Sc.Nstates^2;
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %% relaxation superoperator of the Ir-complex and substrate
    RsC=RLFF_EN(ex.Sc,ex.T1C);
    RsS=RLFF_EN(ex.Ss,ex.T1S);
    %% Yout matrix %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    Zero=zeros(length(ex.Dav),length(ex.timeRFv)); %zero matrix for data output
    Yout{1}=Zero;Yout{2}=Zero;Yout{3}=Zero;
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %% calculate ADAPT-SABRE experiment         
    
    HS_RF=2*pi*HZJij_RF_ULF(ex.Ss,ex.ppmS,ex.JS,ex.B0,ex.v1,ex.vrf,"X");
    HC_RF=2*pi*HZJij_RF_ULF(ex.Sc,ex.ppmC,ex.JC,ex.B0,ex.v1,ex.vrf,"X");
    SABRE_RF=SABRE_MOD2_matrix(rC0,...
                               ex.Ss,HS_RF,RsS,...
                               ex.Sc,HC_RF,RsC,...
                               ex.Sh,...
                               ex.fpH,ex.Wa,ex.Kd);
                           
    HsB=2*pi*HZJij(ex.Ss,ex.ppmS,ex.JS,ex.B0,"full");
    HcB=2*pi*HZJij(ex.Sc,ex.ppmC,ex.JC,ex.B0,"full");   
    SABRE=SABRE_MOD2_matrix(rC0,...
            ex.Ss,HsB,RsS,...
            ex.Sc,HcB,RsC,...
            ex.Sh,...
            ex.fpH,ex.Wa,ex.Kd);
        
    vecS0=mtz2vec(rS0.val)/trace(rS0.val)*SABRE.fs;
    vecC0=mtz2vec(rC0.val)/trace(rC0.val)*SABRE.fc;
    vec0=[vecS0' vecC0']'; 
            
    for iRF=1:length(ex.timeRFv)
        disp(iRF/length(ex.timeRFv)*100);
        timeRF=ex.timeRFv(iRF);
        Rot=expm(SABRE_RF.A*timeRF);
        %(-1i*Op*RF)
        % delay       
        for it=1:length(ex.Dav)
            t=ex.Dav(it);
            vec=((expm(SABRE.A*t)*Rot)^ex.m)*vec0;
            rS.val=vec2mtz(vec(1:NS2))/SABRE.fs;
            rC.val=vec2mtz(vec(NS2+1:NS2+NC2))/SABRE.fc;
            Yts=Amplitudes(rS,ex.SOs);                                
            %Ytc=Amplitudes(rC,ex.SOc);
            for ik = 1:3
                Yout{ik}(it,iRF)=real(Yts(ik));            
            end
        end
    end
end

