function Yout = sabre_MOD2_ULF_SLIC(ex)
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %% nonpolorized initial spin state of the Ir-complex and substrate
    rC0=DensityMatrix(ex.Sc.U);
    rS0=DensityMatrix(ex.Ss.U);
    rS=rS0;
    rC=rC0;
            
    NS2=ex.Ss.Nstates^2;
    NC2=ex.Sc.Nstates^2;
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %% relaxation superoperator of the Ir-complex and substrate
    RsC=RLFF_EN(ex.Sc,ex.T1C);
    RsS=RLFF_EN(ex.Ss,ex.T1S);
    %% Yout matrix %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    Zero=zeros(length(ex.offsetv),length(ex.v1v),length(ex.timeRFv)); %zero matrix for data output
    Yout.c=cell(length(ex.SOc),1);
    Yout.s=cell(length(ex.SOs),1);
    for ik = 1:length(ex.SOc)                    
        Yout.c{ik}=Zero;                    
    end
    for ik = 1:length(ex.SOs)                    
        Yout.s{ik}=Zero;
    end    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %% calculate SLIC-SABRE experiment         
    HsB=2*pi*HZJij(ex.Ss,ex.ppmS,ex.JS,ex.B0,"full");
    HcB=2*pi*HZJij(ex.Sc,ex.ppmC,ex.JC,ex.B0,"full");   
    SABRE=SABRE_MOD2_matrix(rC0,...
            ex.Ss,HsB,RsS,...
            ex.Sc,HcB,RsC,...
            ex.Sh,...
            ex.fpH,ex.Wa,ex.Kd);
    Yout.SABRE = SABRE;
    
    vecS0=mtz2vec(rS0.val)/trace(rS0.val)*SABRE.fs;
    vecC0=mtz2vec(rC0.val)/trace(rC0.val)*SABRE.fc;
    vec0=[vecS0' vecC0']';
    
    vec0=(expm(SABRE.A*ex.prebubble))*vec0;
    
    for iof=1:length(ex.offsetv) 
        disp(iof/length(ex.offsetv)*100);
        vrf=ex.vrfv(iof);
        
        for iv1=1:length(ex.v1v)                                    
            v1=ex.v1v(iv1);            
            HS_RF=2*pi*HZJij_RF_ULF(ex.Ss,ex.ppmS,ex.JS,ex.B0,v1,vrf,"X");
            HC_RF=2*pi*HZJij_RF_ULF(ex.Sc,ex.ppmC,ex.JC,ex.B0,v1,vrf,"X");
            SABRE_RF=SABRE_MOD2_matrix(rC0,...
                                   ex.Ss,HS_RF,RsS,...
                                   ex.Sc,HC_RF,RsC,...
                                   ex.Sh,...
                                   ex.fpH,ex.Wa,ex.Kd);

            %Rot=expm(SABRE_RF.A*timeRF);

            for it=1:length(ex.timeRFv)
                timeRF=ex.timeRFv(it);
                vec=(expm(SABRE_RF.A*timeRF))*vec0;
                
                rS.val=vec2mtz(vec(1:NS2))/SABRE.fs;
                rC.val=vec2mtz(vec(NS2+1:NS2+NC2))/SABRE.fc;
                Yts=real(Amplitudes(rS,ex.SOs));                                
                Ytc=real(Amplitudes(rC,ex.SOc));
                for ik = 1:length(ex.SOc)                    
                    Yout.c{ik}(iof,iv1,it)=real(Ytc(ik));                    
                end
                for ik = 1:length(ex.SOs)                    
                    Yout.s{ik}(iof,iv1,it)=real(Yts(ik));
                end
            end
        end
    end
    for ik = 1:3
        Yout.all{ik}=Yout.s{ik}*SABRE.fs+Yout.c{ik}*SABRE.fc;
    end
end

